meta_package_manager package
============================

Subpackages
-----------

.. toctree::

    meta_package_manager.bitbar
    meta_package_manager.managers
    meta_package_manager.tests

Submodules
----------

meta_package_manager.base module
--------------------------------

.. automodule:: meta_package_manager.base
    :members:
    :undoc-members:
    :show-inheritance:

meta_package_manager.cli module
-------------------------------

.. automodule:: meta_package_manager.cli
    :members:
    :undoc-members:
    :show-inheritance:

meta_package_manager.platform module
------------------------------------

.. automodule:: meta_package_manager.platform
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: meta_package_manager
    :members:
    :undoc-members:
    :show-inheritance:
